@@ -24,7 +24,7 @@ import org.slf4j.Logger;
 
 /*----------------------------------------------------------------------------
  * SPingTask
- * 
+ *
  * Instantiate AbstractTask class. The primary usage intent is to response
  * that this Storlet Daemon is running
  * */
@@ -40,19 +40,13 @@ public class SPingTask extends SAbstractTask {
     }
 
     /*------------------------------------------------------------------------
-     * run
-     * 
+     * exec
+     *
      * The actual response on "ping" command.
      * */
-    public boolean run() {
-        boolean bStatus = true;
-        try {
-            this.sOut_.write((new String("True: OK")).getBytes());
-        } catch (IOException e) {
-            e.printStackTrace();
-            bStatus = false;
-        }
-        return bStatus;
+    @Override
+    public boolean exec() {
+        return respond(this.sOut_, true, new String("OK"), null);
     }
 }
 /* ============================== END OF FILE =============================== */
